#!/usr/bin/python

import datetime,getopt,re,sys

usage ="usage: log2excel.py\n"\
        "Convert a LMG logfile into a comma separated value textfile\n"\
        "for an excel import\n"\
        "Example call: log2excel --infile=log0.dat --outfile=my.xls\n"\
        "\t--help print this\n"\
        "\t--infile=[input file, default is log0.dat]\n"\
        "\t--outfile=[excel csv file, default is log0.xls]\n"\
        "\n"

def main():
    infile = "log0.dat"
    outfile = None
    
    try:
        options,arguments = getopt.getopt(sys.argv[1:],
                                          '',
                                          ['help',
                                           'infile=',
                                           'outfile='
                                           ])

    except getopt.GetoptError:
        print usage
        sys.exit(0)
        
    for o,a in options:
        if o in ("","--help"):
            print usage
            sys.exit(0)
        if o in ("","--infile"):
            infile = a
        if o in ("","--outfile"):
            outfile = a

    try:
        fin = open(infile,'r')
    except:
        print "cannot find/open input file %s" % infile
        sys.exit(0)

    try:
        if outfile == None:
            fout = sys.stdout
        else:
            fout = open(outfile,'w')
    except:
        print "cannot find/open output file %s" % outfile
        sys.exit(0)

    regcol=re.compile(r"YCOL" r"(?P<ycol>.+)" r"=" r"(?P<desc>.+)")
    regcycle=re.compile(r"DX=" r"(?P<cycle>.+)")
    regdate=re.compile(r"DATE=" r"(?P<date>.+)")
    regtime=re.compile(r"X0=" r"(?P<time>.+)")

    header = []

    while True:
        line = fin.readline()[:-2]
        if line == "DATA_ASCII=":
            break
        # parse the header informations for date, time and column
        # descriptions
        res = regdate.search(line)
        if res:
            date = res.group('date')
        res = regtime.search(line)
        if res:
            time = res.group('time')
        res = regcol.search(line)
        if res:
            header.append(res.group('desc')) 

    (day,month,year) = date.split('.')
    (hour,min,sec) = time.split(':')

    fout.write("Date ")
    for h in header:
        fout.write('%s ' % h)
    fout.write('\n')

    lines = fin.read().split('\r\n')
    for l in lines:
        try:
            col = l.split()
            (number,rest) = divmod(float(col[0]),1)
            dt=datetime.datetime(int(year),
                                 int(month),
                                 int(day),
                                 int(hour),
                                 int(min),
                                 int(sec) + int(number),
                                 int(rest * 1000000))
            fout.write('%s ' % dt.strftime("\"%m/%d/%y %H:%M:%S\""))
            fout.write('%f ' % round(float(dt.microsecond/1E06),4))
            for n in range(1,len(col)):
                fout.write('%s ' % col[n])
            fout.write('\n')
        except:
            break
    


main()
